# Generated by Django 4.2.9 on 2024-01-23 22:14

from django.db import migrations, models
import encrypted_model_fields.fields


class Migration(migrations.Migration):
    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DeepLTranslator',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True, verbose_name='Name')),
                ('valid', models.BooleanField(null=True, verbose_name='Valid')),
                ('api_key', encrypted_model_fields.fields.EncryptedCharField()),
            ],
            options={
                'verbose_name': 'DeepL',
                'verbose_name_plural': 'DeepL',
            },
        ),
        migrations.CreateModel(
            name='MicrosoftTranslator',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True, verbose_name='Name')),
                ('valid', models.BooleanField(null=True, verbose_name='Valid')),
                ('api_key', encrypted_model_fields.fields.EncryptedCharField()),
                ('location', models.CharField(max_length=100)),
                ('endpoint', models.CharField(default='https://api.cognitive.microsofttranslator.com', max_length=255)),
            ],
            options={
                'verbose_name': 'Microsoft Translator',
                'verbose_name_plural': 'Microsoft Translator',
            },
        ),
        migrations.CreateModel(
            name='OpenAITranslator',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True, verbose_name='Name')),
                ('valid', models.BooleanField(null=True, verbose_name='Valid')),
                ('api_key', encrypted_model_fields.fields.EncryptedCharField()),
                ('model', models.CharField(default='gpt-3.5-turbo', max_length=100)),
                ('prompt', models.TextField(
                    default='Translate the following to {target_language},only returns translations.\n{text}')),
                ('temperature', models.FloatField(default=0.5)),
                ('max_tokens', models.IntegerField(default=1000)),
            ],
            options={
                'verbose_name': 'OpenAI',
                'verbose_name_plural': 'OpenAI',
            },
        ),
        migrations.CreateModel(
            name='Translated_Content',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('hash', models.BinaryField(max_length=8, unique=True)),
                ('original_content', models.TextField()),
                ('translated_language', models.CharField(max_length=255)),
                ('translated_content', models.TextField()),
                ('tokens', models.IntegerField(default=0)),
                ('characters', models.IntegerField(default=0)),
            ],
        ),
    ]



import json
import httpx
from .base import TranslatorEngine
import logging
from time import sleep
from django.db import models
from django.utils.translation import gettext_lazy as _

class DeepLXTranslator(TranslatorEngine):
    # https://github.com/OwO-Network/DeepLX
    deeplx_api = models.CharField(max_length=255, default="http://127.0.0.1:1188/translate")
    max_characters = models.IntegerField(default=5000)
    interval = models.IntegerField(_("Request Interval(s)"), default=3)
    language_code_map = {
        "English": "EN",
        "Chinese Simplified": "ZH",
        "Russian": "RU",
        "Japanese": "JA",
        "Korean": "KO",
        "Czech": "CS",
        "Danish": "DA",
        "German": "DE",
        "Spanish": "ES",
        "French": "FR",
        "Indonesian": "ID",
        "Italian": "IT",
        "Hungarian": "HU",
        "Norwegian Bokmål": "NB",
        "Dutch": "NL",
        "Polish": "PL",
        "Portuguese": "PT-PT",
        "Swedish": "SV",
        "Turkish": "TR",
    }

    class Meta:
        verbose_name = "DeepLX"
        verbose_name_plural = "DeepLX"

    def validate(self) -> bool:
        try:
            resp = self.translate("Hello World", "Chinese Simplified")
            return resp.get("text") != ""
        except Exception as e:
            return False

    def translate(self, text:str, target_language:str) -> dict:
        logging.info(">>> DeepLX Translate [%s]: %s", target_language, text)
        target_code = self.language_code_map.get(target_language, None)
        translated_text = ''
        try:
            if target_code is None:
                logging.error("DeepLXTranslator->Not support target language:%s", target_language)

            data = {
                "text": text,
                "source_lang": "auto",
                "target_lang": target_code,
            }
            headers = {
              'Content-Type': 'application/json'
            }
            post_data = json.dumps(data)
            resp = httpx.post(url=self.deeplx_api, headers=headers, data=post_data, timeout=10)
            if resp.status_code == 429:
                raise ("DeepLXTranslator-> IP has been blocked by DeepL temporarily")
            translated_text = resp.json()["data"]
        except Exception as e:
            logging.error("DeepLXTranslator->%s: %s", e, text)
        finally:
            sleep(self.interval)
            return {'text': translated_text, "characters": len(text)}




import httpx
from time import sleep
from .base import TranslatorEngine
import logging
from django.db import models
from django.utils.translation import gettext_lazy as _

class GoogleTranslateWebTranslator(TranslatorEngine):
    base_url = models.URLField(_("URL"), default="https://translate.googleapis.com/translate_a/single")
    proxy = models.URLField(_("Proxy(optional)"), null=True, blank=True, default=None)
    interval = models.IntegerField(_("Request Interval(s)"), default=3)
    max_characters = models.IntegerField(default=1000)
    language_code_map = {
        "English": "en",
        "Chinese Simplified": "zh-CN",
        "Chinese Traditional": "zh-TW",
        "Russian": "ru",
        "Japanese": "ja",
        "Korean": "ko",
        "Czech": "cs",
        "Danish": "da",
        "German": "de",
        "Spanish": "es",
        "French": "fr",
        "Indonesian": "id",
        "Italian": "it",
        "Hungarian": "hu",
        "Norwegian Bokmål": "no",
        "Dutch": "nl",
        "Polish": "pl",
        "Portuguese": "pt",
        "Swedish": "sv",
        "Turkish": "tr",
    }

    class Meta:
        verbose_name = "Google Translate(Web)"
        verbose_name_plural = "Google Translate(Web)"

    def validate(self) -> bool:
        results = self.translate("hi", "Chinese Simplified")
        return results.get("text") != ""

    def translate(self, text:str, target_language:str) -> dict:
        logging.info(">>> Google Translate Web Translate [%s]:", target_language)
        target_language = self.language_code_map.get(target_language)
        translated_text = ''
        if target_language is None:
            logging.error("GoogleTranslateWebTranslator->Not support target language:%s", target_language)
            return {'text': translated_text, "characters": len(text)}
        try:
            params = {
                "client": "gtx",
                "sl": "auto",
                "tl": target_language,
                "dt": "t",
                "q": text,
            }
            resp = httpx.get(self.base_url, params=params, timeout=10, proxy=self.proxy)
            resp.raise_for_status()
            resp_json = resp.json()
            if resp_json:
                translated_text = resp_json[0][0][0]
            else:
                logging.error("GoogleTranslateWebTranslator->Invalid response: %s", resp.text)
        except Exception as e:
            logging.error("GoogleTranslateWebTranslator->%s: %s", e, text)
        finally:
            sleep(self.interval)
            return {'text': translated_text, "characters": len(text)}



# Generated by Django 5.0.3 on 2024-04-16 07:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("translator", "0023_azureaitranslator_summary_prompt_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="claudetranslator",
            name="model",
            field=models.CharField(
                default="claude-3-haiku-20240307",
                help_text="e.g. claude-3-haiku-20240307, claude-3-sonnet-20240229, claude-3-opus-20240229",
                max_length=50,
            ),
        ),
        migrations.AlterField(
            model_name="geminitranslator",
            name="model",
            field=models.CharField(
                default="gemini-pro",
                help_text="e.g. gemini-pro, gemini-1.5-pro",
                max_length=100,
            ),
        ),
        migrations.AlterField(
            model_name="moonshotaitranslator",
            name="model",
            field=models.CharField(
                default="moonshot-v1-8k",
                help_text="e.g. moonshot-v1-8k, moonshot-v1-32k, moonshot-v1-128k",
                max_length=100,
            ),
        ),
        migrations.AlterField(
            model_name="openaitranslator",
            name="model",
            field=models.CharField(
                default="gpt-3.5-turbo",
                help_text="e.g. gpt-3.5-turbo, gpt-4-turbo",
                max_length=100,
            ),
        ),
    ]



# Generated by Django 5.0.2 on 2024-02-21 10:42

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('translator', '0015_googletranslatewebtranslator_max_characters'),
    ]

    operations = [
        migrations.AlterField(
            model_name='deeplwebtranslator',
            name='max_characters',
            field=models.IntegerField(default=5000),
        ),
        migrations.AlterField(
            model_name='deeplxtranslator',
            name='max_characters',
            field=models.IntegerField(default=5000),
        ),
        migrations.AlterField(
            model_name='googletranslatewebtranslator',
            name='max_characters',
            field=models.IntegerField(default=1000),
        ),
    ]



# Generated by Django 5.0.1 on 2024-01-30 06:01

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('translator', '0005_caiyuntranslator_deeplxtranslator'),
    ]

    operations = [
        migrations.CreateModel(
            name='TestTranslator',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True, verbose_name='Name')),
                ('valid', models.BooleanField(null=True, verbose_name='Valid')),
                ('translated_text', models.TextField(default='@@Translated Text@@')),
                ('max_characters', models.IntegerField(default=50000)),
            ],
            options={
                'verbose_name': 'Test',
                'verbose_name_plural': 'Test',
            },
        ),
        migrations.AlterField(
            model_name='openaitranslator',
            name='prompt',
            field=models.TextField(
                default='Translate only the text from the following into {target_language},only returns translations.\n{text}'),
        ),
    ]
